# frplib

[![PyPI - Version](https://img.shields.io/pypi/v/frplib.svg)](https://pypi.org/project/frplib)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/frplib.svg)](https://pypi.org/project/frplib)

-----

**frplib** is a library and application that provides a platform for instruction
on probability theory and statistics.

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install frplib
```

## License

`frplib` is distributed under the terms of the
[GNU Affero General Public License](http://www.gnu.org/licenses/) license.

Copyright (C) Christopher R. Genovese
